pub struct Asn1Time(/* private fields */);Expand description
Time storage and comparison
Asn1Time should be used to store and share time information using certificates. If Asn1Time is set using a string, it must be in either YYMMDDHHMMSSZ, YYYYMMDDHHMMSSZ, or another ASN.1 format.
ASN_TIME_set documentation at OpenSSL explains the ASN.1 implementation used by OpenSSL.
Implementations
Sourceimpl Asn1Time
impl Asn1Time
Sourcepub fn days_from_now(days: u32) -> Result<Asn1Time, ErrorStack>
pub fn days_from_now(days: u32) -> Result<Asn1Time, ErrorStack>
Creates a new time on specified interval in days from now
Sourcepub fn from_unix(time: time_t) -> Result<Asn1Time, ErrorStack>
pub fn from_unix(time: time_t) -> Result<Asn1Time, ErrorStack>
Creates a new time from the specified time_t value
This corresponds to ASN1_TIME_set.
Sourcepub fn from_str(s: &str) -> Result<Asn1Time, ErrorStack>
pub fn from_str(s: &str) -> Result<Asn1Time, ErrorStack>
Creates a new time corresponding to the specified ASN1 time string.
This corresponds to ASN1_TIME_set_string.
Methods from Deref<Target = Asn1TimeRef>
Sourcepub fn diff(&self, compare: &Self) -> Result<TimeDiff, ErrorStack>
pub fn diff(&self, compare: &Self) -> Result<TimeDiff, ErrorStack>
Find difference between two times
This corresponds to ASN1_TIME_diff.
Sourcepub fn compare(&self, other: &Self) -> Result<Ordering, ErrorStack>
pub fn compare(&self, other: &Self) -> Result<Ordering, ErrorStack>
Compare two times
This corresponds to ASN1_TIME_compare.